@@ -1,6 +1,8 @@
 package Flickr::API2::Photo;
+use 5.12.0;
+use warnings;
 use Encode::Base58;
-use Mouse;
+use Moo;
 extends 'Flickr::API2::Base';
 
 =head1 NAME
@@ -19,6 +21,10 @@ date_upload
 
 date_taken
 
+count_faves
+
+views
+
 owner_name
 
 url_s url_m url_l
@@ -57,6 +63,7 @@ has 'title' => ( is => 'rw' );
 has 'date_upload' => ( is => 'rw' );
 has 'date_taken' => ( is => 'rw' );
 has 'count_faves' => ( is => 'rw' );
+has 'views' => ( is => 'rw' );
 has 'owner_id' => ( is => 'rw' );
 has 'owner_name' => ( is => 'rw' );
 has 'url_sq' => (
@@ -197,5 +204,4 @@ sub short_url {
     sprintf('http://flic.kr/p/%s', encode_base58($self->id));
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
